"use client";
import React, { useState, useEffect, useRef } from "react";
import PaginationComponent from "./Pagination";
import Image from "next/image";
import Link from "next/link";
// add slider
import { Navigation, Pagination, Scrollbar, A11y } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import "./style.css";

import {
  FaceBookIcon,
  InstaIcon,
  LocationIcon,
  TwitterIcon,
  WhatsAppIcon,
  WhiteLinkdInIcon,
} from "../Icons";
import { useSearchParams } from "next/navigation";

// Define the Swiper instance type
type SwiperInstance = {
  slidePrev: () => void;
  slideNext: () => void;
};

export const AuctionData = ({ initialData }: any) => {
  const searchParams = useSearchParams();
  const [currentPage, setCurrentPage] = useState(1);
  const totalPages = 4; // Total number of pages
  const [data, setData] = useState(initialData);
  // slider refs
  const swiperRefs = useRef<{ [key: string]: SwiperInstance }>({});

  const handlePrevSlide = (id: string) => {
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slidePrev();
    }
  };

  const handleNextSlide = (id: string) => {
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slideNext();
    }
  };

  useEffect(() => {
    const fetchData = async () => {
      const params = new URLSearchParams(searchParams ?? "");
      const res = await fetch(
        `${
          process.env.NEXT_PUBLIC_BASE_URL
        }/property/filter?${params.toString()}`
      );
      const result = await res.json();
      setData(result);
    };

    fetchData();
  }, [searchParams]);

  const modifiedData = [...data.slice(0, 3), { isAd: true }, ...data.slice(3)];

  const handlePageChange = (pageNumber: any) => {
    setCurrentPage(pageNumber);
  };

  return (
    <div className="flex flex-col w-full xl:me-20 gap-6">
      {modifiedData.map((item, index) => {
        if (item.isAd) {
          return (
            <figure key={`ad-${index}`} className="w-full">
              <Link href={`property/${item._id}`}>
                <Image
                  src="/assets/images/ads.png"
                  className="w-full min-h-[115px] rounded object-cover"
                  height={168}
                  width={955}
                  alt="ads"
                />
              </Link>
            </figure>
          );
        }
        return (
          <div
            key={item._id}
            className="flex p-5 flex-col gap-4 xl:gap-10 items-center sm:flex-row custom-shadow"
          >
            <div
              className="w-full sm:w-1/2 relative"
              style={{ maxWidth: "350px" }}
            >
              {/* Previous arrow */}
              <div
                onClick={() => handlePrevSlide(item._id)}
                className="absolute top-[30%] left-10 z-40 h-[100px] w-[25px] flex items-center justify-center bg-[#FFFFFF]"
              >
                <div className="px-2 py-1 rounded">
                  <img
                    src={"/icons/golden-arrow-previous.png"}
                    alt="previous"
                  />
                </div>
              </div>
              {/* Image slider */}
              <Swiper
                spaceBetween={0}
                slidesPerView={1}
                hashNavigation={{
                  watchState: true,
                }}
                loop={true}
                pagination={{ clickable: true }}
                scrollbar={{ draggable: true }}
                style={{ maxWidth: "312px", width: "100%", height: "250px" }}
                modules={[Navigation, Pagination, Scrollbar, A11y]}
                onSwiper={(swiper) => {
                  swiperRefs.current[item._id] = swiper;
                  console.log(`Swiper instance for ${item._id}:`, swiper);
                }}
              >
                {item.pictures?.images.map((image: any, imgIndex: any) => (
                  <SwiperSlide key={imgIndex}>
                    <Image
                      className="rounded-lg !w-[314px] !h-[250px]"
                      src={image.url}
                      height={253}
                      width={314}
                      alt={item.title}
                    />
                  </SwiperSlide>
                ))}
              </Swiper>
              {/* Next arrow */}
              <div
                onClick={() => handleNextSlide(item._id)}
                className="absolute top-[30%] right-10 z-40 h-[100px] w-[25px] flex items-center justify-center bg-[#FFFFFF]"
              >
                <div className="px-2 py-1 rounded">
                  <img
                    src={"/icons/golden-arrow-previous.png"}
                    className="transform rotate-180"
                    alt="next"
                  />
                </div>
              </div>
            </div>
            <div>
              <Link href={`property/${item._id}`}>
                <h2 className="fs-40 font-semibold capitalize">{item.title}</h2>
              </Link>
              <p className="text-reefGold mb-3">{item.price} USD</p>
              <div className="flex flex-wrap gap-3 items-center mb-3">
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.bedrooms} beds</span>
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.bathrooms} Baths</span>
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.sizeSQFT} Sqft</span>
              </div>
              <div className="flex gap-3 items-center mb-3">
                <LocationIcon className="text-reefGold" />
                <p>{item.country}</p>
              </div>
              <div>
                <p className="mb-3">Share With:</p>
                <div className="flex gap-3">
                  <Link href="#">
                    <FaceBookIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <InstaIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhiteLinkdInIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <TwitterIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhatsAppIcon className="h-[21px] w-[21px]" />
                  </Link>
                </div>
              </div>
            </div>
          </div>
        );
      })}
      <PaginationComponent
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
    </div>
  );
};
